package com.usky.fire.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.usky.common.security.utils.SecurityUtils;
import com.usky.fire.domain.*;
import com.usky.fire.mapper.ReportIndexResultMapper;
import com.usky.fire.service.*;
import com.usky.common.mybatis.core.AbstractCrudService;
import com.usky.fire.service.vo.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.text.SimpleDateFormat;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.time.temporal.ChronoUnit;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.List;

/**
 * <p>
 * 指数结果表 服务实现类
 * </p>
 *
 * @author han
 * @since 2023-06-27
 */
@Service
public class ReportIndexResultServiceImpl extends AbstractCrudService<ReportIndexResultMapper, ReportIndexResult> implements ReportIndexResultService {
    @Autowired
    private BaseCompanyService baseCompanyService;
    @Autowired
    private BaseBuildService baseBuildService;
    @Autowired
    private ReportIndexConfigService reportIndexConfigService;
    @Autowired
    private BaseDeviceService baseDeviceService;
    @Autowired
    private BaseDeviceStatusService baseDeviceStatusService;
    @Autowired
    private AlarmFireService alarmFireService;
    @Autowired
    private AlarmSmokeControlService alarmSmokeControlService;
    @Autowired
    private AlarmHydrantWaterService alarmHydrantWaterService;
    @Autowired
    private AlarmSprayWaterService alarmSprayWaterService;
    @Autowired
    private BaseCompanyPersonService baseCompanyPersonService;
    @Autowired
    private DemEnforceInspectRecordService demEnforceInspectRecordService;
    @Autowired
    private DemLawSituationService demLawSituationService;
    @Autowired
    private DemEnforceReportComplaintService demEnforceReportComplaintService;
    @Autowired
    private DemFireStatisticsService demFireStatisticsService;
    @Autowired
    private ReportResultService reportResultService;

    @Override
    public void reportIndexResult() {
        try {
            List<BaseCompany> baseCompanies = baseCompanyService.companyIdByTypeList("1");
            if (CollectionUtils.isNotEmpty(baseCompanies)) {
                Calendar now = Calendar.getInstance();
                LocalDate date=LocalDate.now();
                LocalDateTime dateTime=LocalDateTime.now();
                for (int i = 0; i < baseCompanies.size(); i++) {
                    ReportResult reportResult = new ReportResult();
                    reportResult.setObjectId(baseCompanies.get(i).getId());
                    reportResult.setReportObject(baseCompanies.get(i).getCompanyName());
                    reportResult.setObjectType(1);
                    reportResult.setCreateDate(date);
                    reportResult.setConfigId(1);
                    reportResult.setCreateTime(dateTime);
                    reportResult.setCreateBy(SecurityUtils.getUsername());
                    List<BaseBuildAddVO> baseBuilds =
                            baseBuildService.baseBuildByIdList(baseCompanies.get(i).getCompanyId(), "");
                    List<ReportIndexConfig> indexConfig3 = reportIndexConfigService.indexConfigList(1, 3);
                    List<ReportIndexConfig> indexConfig2 = reportIndexConfigService.indexConfigList(1, 2);
                    List<ReportIndexConfig> indexConfig1 = reportIndexConfigService.indexConfigList(1, 1);
                    int fireDeviceNum = baseDeviceService.deviceCount(baseCompanies.get(i).getCompanyId(), 1);
                    int smokeDeviceNum = baseDeviceService.deviceCount(baseCompanies.get(i).getCompanyId(), 3);
                    int fireDeviceOfflineNum =
                            baseDeviceStatusService.deviceStatusByTypeCount(baseCompanies.get(i).getCompanyId(), 0, 1);
                    int smokeDeviceOfflineNum =
                            baseDeviceStatusService.deviceStatusByTypeCount(baseCompanies.get(i).getCompanyId(), 0, 3);
                    int fireDeviceHitchNum =
                            baseDeviceStatusService.deviceStatusByTypeCount(baseCompanies.get(i).getCompanyId(), 2, 1);
                    int smokeDeviceHitchNum =
                            baseDeviceStatusService.deviceStatusByTypeCount(baseCompanies.get(i).getCompanyId(), 2, 3);
                    int fireAlarmOfflineNum = fireDeviceOfflineNum + smokeDeviceOfflineNum;
                    int fireAlarmHitchNum = fireDeviceHitchNum + smokeDeviceHitchNum;
                    int fireAlarmNum = fireDeviceNum + smokeDeviceNum;
                    double fireOnlineRate = 0;
                    double fireFaultRate = 0;
                    if (fireAlarmNum > 0) {
                        fireOnlineRate = 1 - Math.round(fireAlarmOfflineNum / fireAlarmNum * 100) * 0.01;
                        fireFaultRate = Math.round(fireAlarmHitchNum / fireAlarmNum * 100) * 0.01;
                    }
                    SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd");
                    Calendar lastMonthFirstDateCal = Calendar.getInstance();
                    lastMonthFirstDateCal.add(Calendar.MONTH, -1);
                    String lastMonthFirstTime = format.format(lastMonthFirstDateCal.getTime());
                    Calendar lastYearFirstDateCal = Calendar.getInstance();
                    lastYearFirstDateCal.add(Calendar.YEAR, -2);
                    String lastYearFirstTime = format.format(lastYearFirstDateCal.getTime());
                    Calendar lastYearFirstDateCal2 = Calendar.getInstance();
                    lastYearFirstDateCal2.add(Calendar.YEAR, -1);
                    String lastYearFirstTime2 = format.format(lastYearFirstDateCal2.getTime());
                    Integer fireAlarmWcl = alarmFireService.fireAlarmCount(baseCompanies.get(i).getCompanyId(), 0,
                            "101", lastYearFirstTime2, lastMonthFirstTime);
                    LambdaQueryWrapper<AlarmFire> queryWrapper6 = Wrappers.lambdaQuery();
                    queryWrapper6.eq(AlarmFire::getCompanyId, baseCompanies.get(i).getCompanyId())
                            .eq(AlarmFire::getHandlingStatus, 1)
                            .last("limit 1");
                    List<AlarmFire> list6 = alarmFireService.list(queryWrapper6);
                    long clFireDays = 0;
                    if (CollectionUtils.isNotEmpty(list6)) {
                        clFireDays = ChronoUnit.DAYS.between(list6.get(0).getAlarmTime(),
                                list6.get(0).getHandlingTime());
                    }
                    LambdaQueryWrapper<BaseDevice> queryWrapper2 = Wrappers.lambdaQuery();
                    queryWrapper2.select(BaseDevice::getId, BaseDevice::getDeviceCode)
                            .eq(BaseDevice::getCompanyId, baseCompanies.get(i).getCompanyId())
                            .in(BaseDevice::getDeviceType, 2, 5, 6)
                            .notLike(BaseDevice::getDeviceName, "风机");
                    List<BaseDevice> list2 = baseDeviceService.list(queryWrapper2);
                    double waterOnlineRate = 0;
                    double waterFaultRate = 0;
                    Integer waterAlarmWcl = 0;
                    long clHydrantWaterDays = 0;
                    if (CollectionUtils.isNotEmpty(list2)) {
                        List<String> deviceCodeList = new ArrayList<>();
                        for (int j = 0; j < list2.size(); j++) {
                            deviceCodeList.add(list2.get(j).getDeviceCode());
                        }
                        List<BaseDeviceStatus> list3 = new ArrayList<>();
                        List<BaseDeviceStatus> list3l = new ArrayList<>();
                        if (CollectionUtils.isNotEmpty(deviceCodeList)) {
                            LambdaQueryWrapper<BaseDeviceStatus> queryWrapper3 = Wrappers.lambdaQuery();
                            queryWrapper3.select(BaseDeviceStatus::getId, BaseDeviceStatus::getDeviceCode)
                                    .in(BaseDeviceStatus::getDeviceCode, deviceCodeList)
                                    .ne(BaseDeviceStatus::getDeviceStatus, 0);
                            list3 = baseDeviceStatusService.list(queryWrapper3);
                            waterOnlineRate = Math.round(list3.size() / list2.size() * 100) * 0.01;
                            LambdaQueryWrapper<BaseDeviceStatus> queryWrapper3l = Wrappers.lambdaQuery();
                            queryWrapper3l.select(BaseDeviceStatus::getId, BaseDeviceStatus::getDeviceCode)
                                    .in(BaseDeviceStatus::getDeviceCode, deviceCodeList)
                                    .eq(BaseDeviceStatus::getDeviceStatus, 2);
                            list3l = baseDeviceStatusService.list(queryWrapper3l);
                            waterFaultRate = Math.round(list3l.size() / list2.size() * 100) * 0.01;
                        }
                        waterAlarmWcl = alarmHydrantWaterService.hydrantWaterCount(baseCompanies.get(i).getCompanyId(), 0,
                                lastYearFirstTime2, lastMonthFirstTime);
                        LambdaQueryWrapper<AlarmHydrantWater> queryWrapper7 = Wrappers.lambdaQuery();
                        queryWrapper7.eq(AlarmHydrantWater::getCompanyId, baseCompanies.get(i).getCompanyId())
                                .eq(AlarmHydrantWater::getHandlingStatus, 1)
                                .last("limit 1");
                        List<AlarmHydrantWater> list7 = alarmHydrantWaterService.list(queryWrapper7);
                        if (CollectionUtils.isNotEmpty(list7)) {
                            clHydrantWaterDays = ChronoUnit.DAYS.between(list7.get(0).getAlarmTime(),
                                    list7.get(0).getHandlingTime());
                        }
                    }
                    LambdaQueryWrapper<BaseDevice> queryWrapper4 = Wrappers.lambdaQuery();
                    queryWrapper4.select(BaseDevice::getId, BaseDevice::getDeviceCode)
                            .eq(BaseDevice::getCompanyId, baseCompanies.get(i).getCompanyId())
                            .eq(BaseDevice::getDeviceType, 6)
                            .like(BaseDevice::getDeviceName, "风机");
                    List<BaseDevice> list4 = baseDeviceService.list(queryWrapper4);
                    double smokeOnlineRate = 0;
                    double smokeFaultRate = 0;
                    Integer smokeAlarmWcl = 0;
                    long clSmokeDays = 0;
                    if (CollectionUtils.isNotEmpty(list4)) {
                        List<String> deviceCodeList = new ArrayList<>();
                        for (int j = 0; j < list4.size(); j++) {
                            deviceCodeList.add(list4.get(j).getDeviceCode());
                        }
                        List<BaseDeviceStatus> list5 = new ArrayList<>();
                        List<BaseDeviceStatus> list5l = new ArrayList<>();
                        if (CollectionUtils.isNotEmpty(deviceCodeList)) {
                            LambdaQueryWrapper<BaseDeviceStatus> queryWrapper5 = Wrappers.lambdaQuery();
                            queryWrapper5.select(BaseDeviceStatus::getId, BaseDeviceStatus::getDeviceCode)
                                    .in(BaseDeviceStatus::getDeviceCode, deviceCodeList)
                                    .ne(BaseDeviceStatus::getDeviceStatus, 0);
                            list5 = baseDeviceStatusService.list(queryWrapper5);
                            smokeOnlineRate = Math.round(list5.size() / list4.size()) * 0.01;
                            LambdaQueryWrapper<BaseDeviceStatus> queryWrapper5l = Wrappers.lambdaQuery();
                            queryWrapper5l.select(BaseDeviceStatus::getId, BaseDeviceStatus::getDeviceCode)
                                    .in(BaseDeviceStatus::getDeviceCode, deviceCodeList)
                                    .ne(BaseDeviceStatus::getDeviceStatus, 2);
                            list5l = baseDeviceStatusService.list(queryWrapper5l);
                            smokeFaultRate = Math.round(list5l.size() / list4.size()) * 0.01;
                        }
                        smokeAlarmWcl = alarmSmokeControlService.smokeControlCount(baseCompanies.get(i).getCompanyId(), 0,
                                lastYearFirstTime2, lastMonthFirstTime);
                        LambdaQueryWrapper<AlarmSmokeControl> queryWrapper8 = Wrappers.lambdaQuery();
                        queryWrapper8.eq(AlarmSmokeControl::getCompanyId, baseCompanies.get(i).getCompanyId())
                                .eq(AlarmSmokeControl::getHandlingStatus, 1)
                                .last("limit 1");
                        List<AlarmSmokeControl> list8 = alarmSmokeControlService.list(queryWrapper8);
                        if (CollectionUtils.isNotEmpty(list8)) {
                            clSmokeDays = ChronoUnit.DAYS.between(list8.get(0).getAlarmTime(),
                                    list8.get(0).getHandlingTime());
                        }
                    }
                    LambdaQueryWrapper<BaseCompanyPerson> queryWrapperPerson = Wrappers.lambdaQuery();
                    queryWrapperPerson.select(BaseCompanyPerson::getFireManageName)
                            .eq(BaseCompanyPerson::getCompanyId, baseCompanies.get(i).getCompanyId());
                    List<BaseCompanyPerson> list9 =
                            baseCompanyPersonService.list(queryWrapperPerson);
                    LambdaQueryWrapper<DemEnforceInspectRecord> queryWrapper10 = Wrappers.lambdaQuery();
                    queryWrapper10.select(DemEnforceInspectRecord::getId)
                            .like(DemEnforceInspectRecord::getCompanyName, baseCompanies.get(i).getCompanyName())
                            .eq(DemEnforceInspectRecord::getInspectQualified, 0)
                            .between(DemEnforceInspectRecord::getInspectEndTime, lastYearFirstTime, date);
                    List<DemEnforceInspectRecord> list10 = demEnforceInspectRecordService.list(queryWrapper10);
                    Calendar lastYearFirstDateCal3 = Calendar.getInstance();
                    lastYearFirstDateCal3.add(Calendar.YEAR, -3);
                    String lastYearFirstTime3 = format.format(lastYearFirstDateCal3.getTime());
                    LambdaQueryWrapper<DemLawSituation> queryWrapper11 = Wrappers.lambdaQuery();
                    queryWrapper11.select(DemLawSituation::getId)
                            .like(DemLawSituation::getPunishedPerson, baseCompanies.get(i).getCompanyName())
                            .eq(DemLawSituation::getEnable, 0)
                            .between(DemLawSituation::getPunishmentDecisionTime, lastYearFirstTime3, date);
                    List<DemLawSituation> list11 = demLawSituationService.list(queryWrapper11);
                    LambdaQueryWrapper<DemEnforceReportComplaint> queryWrapper12 = Wrappers.lambdaQuery();
                    queryWrapper12.select(DemEnforceReportComplaint::getId)
                            .like(DemEnforceReportComplaint::getReportAddress, baseCompanies.get(i).getAddress())
                            .eq(DemEnforceReportComplaint::getEnable, 0)
                            .in(DemEnforceReportComplaint::getFactFind, 1, 2)
                            .between(DemEnforceReportComplaint::getReportTime, lastYearFirstTime, date);
                    List<DemEnforceReportComplaint> list12 = demEnforceReportComplaintService.list(queryWrapper12);
                    Calendar lastYearFirstDateCal1 = Calendar.getInstance();
                    lastYearFirstDateCal1.add(Calendar.YEAR, -1);
                    String lastYearFirstTime1 = format.format(lastYearFirstDateCal1.getTime());
                    LambdaQueryWrapper<DemFireStatistics> queryWrapper13 = Wrappers.lambdaQuery();
                    queryWrapper13.select(DemFireStatistics::getId)
                            .like(DemFireStatistics::getFireAddress, baseCompanies.get(i).getAddress())
                            .between(DemFireStatistics::getFireTime, lastYearFirstTime1, date);
                    List<DemFireStatistics> list13 = demFireStatisticsService.list(queryWrapper13);
                    if (CollectionUtils.isNotEmpty(indexConfig1)) {
                        for (int l = 0; l < indexConfig1.size(); l++) {
                            ReportIndexResult reportIndexResult1 = new ReportIndexResult();
                            reportIndexResult1.setIndexCode(indexConfig1.get(l).getIndexCode());
                            reportIndexResult1.setIndexName(indexConfig1.get(l).getIndexName());
                            reportIndexResult1.setObjectId(baseCompanies.get(i).getId());
                            reportIndexResult1.setCreateDate(date);
                            reportIndexResult1.setScoreDesc(indexConfig1.get(l).getIndexDesc());
                            if (CollectionUtils.isNotEmpty(indexConfig2)) {
                                for (int k = 0; k < indexConfig2.size(); k++) {
                                    if (indexConfig1.get(l).getId().equals(indexConfig2.get(k).getSeniorIndex())) {
                                        ReportIndexResult reportIndexResult2 = new ReportIndexResult();
                                        reportIndexResult2.setIndexCode(indexConfig2.get(k).getIndexCode());
                                        reportIndexResult2.setIndexName(indexConfig2.get(k).getIndexName());
                                        reportIndexResult2.setObjectId(baseCompanies.get(i).getId());
                                        reportIndexResult2.setCreateDate(date);
                                        reportIndexResult2.setScoreDesc(indexConfig2.get(k).getIndexDesc());
                                        if (CollectionUtils.isNotEmpty(indexConfig3)) {
                                            for (int j = 0; j < indexConfig3.size(); j++) {
                                                if (indexConfig2.get(k).getId().equals(indexConfig3.get(j).getSeniorIndex())) {
                                                    ReportIndexResult reportIndexResult = new ReportIndexResult();
                                                    reportIndexResult.setIndexCode(indexConfig3.get(j).getIndexCode());
                                                    reportIndexResult.setIndexName(indexConfig3.get(j).getIndexName());
                                                    reportIndexResult.setObjectId(baseCompanies.get(i).getId());
                                                    reportIndexResult.setCreateDate(date);
                                                    reportIndexResult.setScoreDesc(indexConfig3.get(j).getIndexDesc());
                                                    if (CollectionUtils.isNotEmpty(baseBuilds)) {
                                                        reportIndexResult.setScoreType(1);
                                                        if (indexConfig3.get(j).getSeniorIndex().equals(2)) {
                                                            if (indexConfig3.get(j).getIndexCode().equals("10024")) {
                                                                reportIndexResult.setIndexData(baseBuilds.get(0).getBaseBuild().getFireRating().toString());
                                                                if (baseBuilds.get(0).getBaseBuild().getFireRating().equals(1)) {
                                                                    reportIndexResult.setIndexScore(100 * indexConfig3.get(j).getIndexWeight());
                                                                    reportIndexResult2.setIndexScore(100 * indexConfig3.get(j).getIndexWeight() * indexConfig2.get(k).getIndexWeight());
                                                                } else if (baseBuilds.get(0).getBaseBuild().getFireRating().equals(2)) {
                                                                    reportIndexResult.setIndexScore(75 * indexConfig3.get(j).getIndexWeight());
                                                                    reportIndexResult2.setIndexScore(75 * indexConfig3.get(j).getIndexWeight() * indexConfig2.get(k).getIndexWeight());
                                                                } else if (baseBuilds.get(0).getBaseBuild().getFireRating().equals(3)) {
                                                                    reportIndexResult.setIndexScore(50 * indexConfig3.get(j).getIndexWeight());
                                                                    reportIndexResult2.setIndexScore(50 * indexConfig3.get(j).getIndexWeight() * indexConfig2.get(k).getIndexWeight());
                                                                } else {
                                                                    reportIndexResult.setIndexScore(25 * indexConfig3.get(j).getIndexWeight());
                                                                    reportIndexResult2.setIndexScore(25 * indexConfig3.get(j).getIndexWeight() * indexConfig2.get(k).getIndexWeight());
                                                                }
                                                            }
                                                            this.save(reportIndexResult);
                                                        }else if (indexConfig3.get(j).getSeniorIndex().equals(7)){
                                                            if (indexConfig3.get(j).getIndexCode().equals("10025")) {
                                                                reportIndexResult.setIndexData(baseBuilds.get(0).getBaseBuild().getAboveFloor().toString());
                                                                if (baseBuilds.get(0).getBaseBuild().getAboveFloor() < 10) {
                                                                    reportIndexResult.setIndexScore(100 * indexConfig3.get(j).getIndexWeight());
                                                                    if (reportIndexResult2.getIndexScore()!=null){
                                                                        reportIndexResult2.setIndexScore(100 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                                    }else {
                                                                        reportIndexResult2.setIndexScore(100 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                    }
                                                                } else if (baseBuilds.get(0).getBaseBuild().getAboveFloor() > 10 && baseBuilds.get(0).getBaseBuild().getAboveFloor() < 40) {
                                                                    reportIndexResult.setIndexScore(66.67 * indexConfig3.get(j).getIndexWeight());
                                                                    if (reportIndexResult2.getIndexScore()!=null){
                                                                        reportIndexResult2.setIndexScore(66.67 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                                    }else{
                                                                        reportIndexResult2.setIndexScore(66.67 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                    }
                                                                } else {
                                                                    if (reportIndexResult2.getIndexScore()!=null){
                                                                        reportIndexResult2.setIndexScore(33.33 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                                    }else {
                                                                        reportIndexResult2.setIndexScore(33.33 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                    }
                                                                    reportIndexResult.setIndexScore(33.33 * indexConfig3.get(j).getIndexWeight());
                                                                }
                                                            } else if (indexConfig3.get(j).getIndexCode().equals("10026")) {
                                                                reportIndexResult.setIndexData(baseBuilds.get(0).getBaseBuild().getUnderSpace().toString());
                                                                if (baseBuilds.get(0).getBaseBuild().getUnderSpace() > 20000) {
                                                                    reportIndexResult.setIndexScore(-100 * indexConfig3.get(j).getIndexWeight());
                                                                    if (reportIndexResult2.getIndexScore()!=null){
                                                                        reportIndexResult2.setIndexScore(-100 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                                    }else {
                                                                        reportIndexResult2.setIndexScore(-100 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                    }
                                                                } else if (baseBuilds.get(0).getBaseBuild().getUnderSpace() > 10000 && baseBuilds.get(0).getBaseBuild().getUnderSpace() < 20000) {
                                                                    reportIndexResult.setIndexScore(-75 * indexConfig3.get(j).getIndexWeight());
                                                                    if (reportIndexResult2.getIndexScore()!=null){
                                                                        reportIndexResult2.setIndexScore(-75 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                                    }else {
                                                                        reportIndexResult2.setIndexScore(-75 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                    }
                                                                } else if (baseBuilds.get(0).getBaseBuild().getUnderSpace() > 5000 && baseBuilds.get(0).getBaseBuild().getUnderSpace() < 10000) {
                                                                    reportIndexResult.setIndexScore(-50 * indexConfig3.get(j).getIndexWeight());
                                                                    if (reportIndexResult2.getIndexScore()!=null){
                                                                        reportIndexResult2.setIndexScore(-50 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                                    }else {
                                                                        reportIndexResult2.setIndexScore(-50 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                    }
                                                                } else {
                                                                    reportIndexResult.setIndexScore(-25 * indexConfig3.get(j).getIndexWeight());
                                                                    if (reportIndexResult2.getIndexScore()!=null){
                                                                        reportIndexResult2.setIndexScore(-25 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                                    }else {
                                                                        reportIndexResult2.setIndexScore(-25 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                    }
                                                                }
                                                            }
                                                            this.save(reportIndexResult);
                                                        }else if (indexConfig3.get(j).getSeniorIndex().equals(8)){
                                                            if (indexConfig3.get(j).getIndexCode().equals("10027")) {
                                                                reportIndexResult.setIndexData(baseBuilds.get(0).getBaseBuild().getUseCharacter().toString());
                                                                if (baseBuilds.get(0).getBaseBuild().getUseCharacter().equals(16)) {
                                                                    reportIndexResult.setIndexScore(0 * indexConfig3.get(j).getIndexWeight());
                                                                    reportIndexResult2.setIndexScore(0 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                } else if (baseBuilds.get(0).getBaseBuild().getUseCharacter().equals(14) || baseBuilds.get(0).getBaseBuild().getUseCharacter().equals(15)) {
                                                                    reportIndexResult.setIndexScore(50 * indexConfig3.get(j).getIndexWeight());
                                                                    reportIndexResult2.setIndexScore(50 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                } else if (baseBuilds.get(0).getBaseBuild().getUseCharacter().equals(2)) {
                                                                    reportIndexResult.setIndexScore(75 * indexConfig3.get(j).getIndexWeight());
                                                                    reportIndexResult2.setIndexScore(75 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                } else {
                                                                    reportIndexResult.setIndexScore(100 * indexConfig3.get(j).getIndexWeight());
                                                                    reportIndexResult2.setIndexScore(100 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                }
                                                            } else if (indexConfig3.get(j).getIndexCode().equals("10028")) {
                                                                reportIndexResult.setIndexScore(0 * indexConfig3.get(j).getIndexWeight());
                                                                reportIndexResult.setScoreType(0);
                                                            }
                                                            this.save(reportIndexResult);
                                                        }else if (indexConfig3.get(j).getSeniorIndex().equals(9)){
                                                             if (indexConfig3.get(j).getIndexCode().equals("10029")) {
                                                                reportIndexResult.setIndexData(baseBuilds.get(0).getBaseBuild().getCompleteYear().toString());
                                                                long days = date.toEpochDay() - baseBuilds.get(0).getBaseBuild().getCompleteYear().toEpochDay();
                                                                if (days < 7300) {
                                                                    reportIndexResult.setIndexScore(100 * indexConfig3.get(j).getIndexWeight());
                                                                    reportIndexResult2.setIndexScore(100 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                } else {
                                                                    reportIndexResult.setIndexScore(0 * indexConfig3.get(j).getIndexWeight());
                                                                    reportIndexResult2.setIndexScore(0 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                }
                                                            }
                                                            this.save(reportIndexResult);
                                                        }
                                                    } else {
                                                        if (indexConfig3.get(j).getSeniorIndex().equals(2) || indexConfig3.get(j).getSeniorIndex().equals(7) || indexConfig3.get(j).getSeniorIndex().equals(8) || indexConfig3.get(j).getSeniorIndex().equals(9)) {
                                                            if (indexConfig3.get(j).getIndexCode().equals("10026") || indexConfig3.get(j).getIndexCode().equals("10028")) {
                                                                reportIndexResult.setIndexScore(0.00);
                                                            } else {
                                                                reportIndexResult.setIndexScore(50 * indexConfig3.get(j).getIndexWeight());
                                                            }
                                                            reportIndexResult.setScoreType(0);
                                                            reportIndexResult2.setIndexScore(50 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                            this.save(reportIndexResult);
                                                        }
                                                    }
                                                    if (indexConfig3.get(j).getSeniorIndex().equals(10)) {
                                                        if (fireAlarmNum == 0) {
                                                            reportIndexResult.setScoreType(0);
                                                            if (indexConfig3.get(j).getIndexCode().equals("10030")) {
                                                                reportIndexResult.setIndexScore(-50 * indexConfig3.get(j).getIndexWeight());
                                                                if (reportIndexResult2.getIndexScore()!=null){
                                                                    reportIndexResult2.setIndexScore(-50 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                                }else {
                                                                    reportIndexResult2.setIndexScore(-50 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                }
                                                            } else if (indexConfig3.get(j).getIndexCode().equals("10031")) {
                                                                reportIndexResult.setIndexScore(-50 * indexConfig3.get(j).getIndexWeight());
                                                                if (reportIndexResult2.getIndexScore()!=null){
                                                                    reportIndexResult2.setIndexScore(-50 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                                }else {
                                                                    reportIndexResult2.setIndexScore(-50 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                }
                                                            } else {
                                                                reportIndexResult.setIndexScore(50 * indexConfig3.get(j).getIndexWeight());
                                                                if (reportIndexResult2.getIndexScore()!=null){
                                                                    reportIndexResult2.setIndexScore(50 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                                }else {
                                                                    reportIndexResult2.setIndexScore(50 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                }
                                                            }
                                                        } else {
                                                            reportIndexResult.setScoreType(1);
                                                            if (indexConfig3.get(j).getIndexCode().equals("10030")) {
                                                                reportIndexResult.setIndexData(String.valueOf(fireOnlineRate));
                                                                if (fireOnlineRate < 0.95) {
                                                                    reportIndexResult.setIndexScore(-100 * indexConfig3.get(j).getIndexWeight());
                                                                    if (reportIndexResult2.getIndexScore()!=null){
                                                                        reportIndexResult2.setIndexScore(-100 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                                    }else {
                                                                        reportIndexResult2.setIndexScore(-100 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                    }
                                                                } else {
                                                                    reportIndexResult.setIndexScore(0 * indexConfig3.get(j).getIndexWeight());
                                                                    if (reportIndexResult2.getIndexScore()!=null){
                                                                        reportIndexResult2.setIndexScore(0 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                                    }else {
                                                                        reportIndexResult2.setIndexScore(0 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                    }
                                                                }
                                                            } else if (indexConfig3.get(j).getIndexCode().equals("10031")) {
                                                                reportIndexResult.setIndexData(String.valueOf(fireFaultRate));
                                                                if (fireFaultRate > 0.05) {
                                                                    reportIndexResult.setIndexScore(-100 * indexConfig3.get(j).getIndexWeight());
                                                                    if (reportIndexResult2.getIndexScore()!=null){
                                                                        reportIndexResult2.setIndexScore(-100 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                                    }else {
                                                                        reportIndexResult2.setIndexScore(-100 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                    }
                                                                } else {
                                                                    reportIndexResult.setIndexScore(0 * indexConfig3.get(j).getIndexWeight());
                                                                    if (reportIndexResult2.getIndexScore()!=null){
                                                                        reportIndexResult2.setIndexScore(0 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                                    }else {
                                                                        reportIndexResult2.setIndexScore(0 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                    }
                                                                }
                                                            } else if (indexConfig3.get(j).getIndexCode().equals("10032")) {
                                                                reportIndexResult.setIndexData(String.valueOf(fireOnlineRate));
                                                                if (fireOnlineRate > 0.9) {
                                                                    reportIndexResult.setIndexScore(100 * indexConfig3.get(j).getIndexWeight());
                                                                    if (reportIndexResult2.getIndexScore()!=null){
                                                                        reportIndexResult2.setIndexScore(100 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                                    }else {
                                                                        reportIndexResult2.setIndexScore(100 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                    }
                                                                } else {
                                                                    reportIndexResult.setIndexScore(0 * indexConfig3.get(j).getIndexWeight());
                                                                    if (reportIndexResult2.getIndexScore()!=null){
                                                                        reportIndexResult2.setIndexScore(0 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                                    }else {
                                                                        reportIndexResult2.setIndexScore(0 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                    }
                                                                }
                                                            } else if (indexConfig3.get(j).getIndexCode().equals("10033")) {
                                                                reportIndexResult.setIndexData(String.valueOf(fireFaultRate));
                                                                if (fireFaultRate < 0.05) {
                                                                    reportIndexResult.setIndexScore(100 * indexConfig3.get(j).getIndexWeight());
                                                                    if (reportIndexResult2.getIndexScore()!=null){
                                                                        reportIndexResult2.setIndexScore(100 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                                    }else {
                                                                        reportIndexResult2.setIndexScore(100 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                    }
                                                                } else {
                                                                    reportIndexResult.setIndexScore(0 * indexConfig3.get(j).getIndexWeight());
                                                                    if (reportIndexResult2.getIndexScore()!=null){
                                                                        reportIndexResult2.setIndexScore(0 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                                    }else {
                                                                        reportIndexResult2.setIndexScore(0 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                    }
                                                                }
                                                            } else if (indexConfig3.get(j).getIndexCode().equals("10034")) {
                                                                reportIndexResult.setIndexData(String.valueOf(fireAlarmWcl));
                                                                if (fireAlarmWcl > 0) {
                                                                    reportIndexResult.setIndexScore(-15 * indexConfig3.get(j).getIndexWeight());
                                                                    if (reportIndexResult2.getIndexScore()!=null){
                                                                        reportIndexResult2.setIndexScore(-15 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                                    }else {
                                                                        reportIndexResult2.setIndexScore(-15 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                    }
                                                                } else if (clFireDays < 7) {
                                                                    reportIndexResult.setIndexScore(100 * indexConfig3.get(j).getIndexWeight());
                                                                    if (reportIndexResult2.getIndexScore()!=null){
                                                                        reportIndexResult2.setIndexScore(100 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                                    }else {
                                                                        reportIndexResult2.setIndexScore(100 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                    }
                                                                } else if (clFireDays < 30) {
                                                                    reportIndexResult.setIndexScore(25 * indexConfig3.get(j).getIndexWeight());
                                                                    if (reportIndexResult2.getIndexScore()!=null){
                                                                        reportIndexResult2.setIndexScore(25 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                                    }else {
                                                                        reportIndexResult2.setIndexScore(25 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                    }
                                                                } else {
                                                                    reportIndexResult.setIndexScore(0 * indexConfig3.get(j).getIndexWeight());
                                                                    if (reportIndexResult2.getIndexScore()!=null){
                                                                        reportIndexResult2.setIndexScore(0 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                                    }else {
                                                                        reportIndexResult2.setIndexScore(0 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                    }
                                                                }
                                                            }
                                                        }
                                                        this.save(reportIndexResult);
                                                    }
                                                    if (indexConfig3.get(j).getSeniorIndex().equals(11)) {
                                                        if (list2.size() == 0) {
                                                            reportIndexResult.setScoreType(0);
                                                            if (indexConfig3.get(j).getIndexCode().equals("10035")) {
                                                                reportIndexResult.setIndexScore(-50 * indexConfig3.get(j).getIndexWeight());
                                                                if (reportIndexResult2.getIndexScore()!=null){
                                                                    reportIndexResult2.setIndexScore(-50 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                                }else {
                                                                    reportIndexResult2.setIndexScore(-50 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                }
                                                            } else if (indexConfig3.get(j).getIndexCode().equals("10036")) {
                                                                reportIndexResult.setIndexScore(-50 * indexConfig3.get(j).getIndexWeight());
                                                                if (reportIndexResult2.getIndexScore()!=null){
                                                                    reportIndexResult2.setIndexScore(-50 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                                }else {
                                                                    reportIndexResult2.setIndexScore(-50 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                }
                                                            } else {
                                                                reportIndexResult.setIndexScore(50 * indexConfig3.get(j).getIndexWeight());
                                                                if (reportIndexResult2.getIndexScore()!=null){
                                                                    reportIndexResult2.setIndexScore(50 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                                }else {
                                                                    reportIndexResult2.setIndexScore(50 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                }
                                                            }
                                                        } else {
                                                            reportIndexResult.setScoreType(1);
                                                            if (indexConfig3.get(j).getIndexCode().equals("10035")) {
                                                                reportIndexResult.setIndexData(String.valueOf(waterOnlineRate));
                                                                if (waterOnlineRate < 0.95) {
                                                                    reportIndexResult.setIndexScore(-100 * indexConfig3.get(j).getIndexWeight());
                                                                    if (reportIndexResult2.getIndexScore()!=null){
                                                                        reportIndexResult2.setIndexScore(-100 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                                    }else {
                                                                        reportIndexResult2.setIndexScore(-100 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                    }
                                                                } else {
                                                                    reportIndexResult.setIndexScore(0 * indexConfig3.get(j).getIndexWeight());
                                                                    if (reportIndexResult2.getIndexScore()!=null){
                                                                        reportIndexResult2.setIndexScore(0 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                                    }else {
                                                                        reportIndexResult2.setIndexScore(0 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                    }
                                                                }
                                                            } else if (indexConfig3.get(j).getIndexCode().equals("10036")) {
                                                                reportIndexResult.setIndexData(String.valueOf(waterFaultRate));
                                                                if (waterFaultRate > 0.05) {
                                                                    reportIndexResult.setIndexScore(-100 * indexConfig3.get(j).getIndexWeight());
                                                                    if (reportIndexResult2.getIndexScore()!=null){
                                                                        reportIndexResult2.setIndexScore(-100 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                                    }else {
                                                                        reportIndexResult2.setIndexScore(-100 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                    }
                                                                } else {
                                                                    reportIndexResult.setIndexScore(0 * indexConfig3.get(j).getIndexWeight());
                                                                    if (reportIndexResult2.getIndexScore()!=null){
                                                                        reportIndexResult2.setIndexScore(0 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                                    }else {
                                                                        reportIndexResult2.setIndexScore(0 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                    }
                                                                }
                                                            } else if (indexConfig3.get(j).getIndexCode().equals("10037")) {
                                                                reportIndexResult.setIndexData(String.valueOf(waterOnlineRate));
                                                                if (waterOnlineRate > 0.9) {
                                                                    reportIndexResult.setIndexScore(100 * indexConfig3.get(j).getIndexWeight());
                                                                    if (reportIndexResult2.getIndexScore()!=null){
                                                                        reportIndexResult2.setIndexScore(100 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                                    }else {
                                                                        reportIndexResult2.setIndexScore(100 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                    }
                                                                } else {
                                                                    reportIndexResult.setIndexScore(0 * indexConfig3.get(j).getIndexWeight());
                                                                    if (reportIndexResult2.getIndexScore()!=null){
                                                                        reportIndexResult2.setIndexScore(0 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                                    }else {
                                                                        reportIndexResult2.setIndexScore(0 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                    }
                                                                }
                                                            } else if (indexConfig3.get(j).getIndexCode().equals("10038")) {
                                                                reportIndexResult.setIndexData(String.valueOf(waterFaultRate));
                                                                if (waterFaultRate < 0.05) {
                                                                    reportIndexResult.setIndexScore(100 * indexConfig3.get(j).getIndexWeight());
                                                                    if (reportIndexResult2.getIndexScore()!=null){
                                                                        reportIndexResult2.setIndexScore(100 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                                    }else {
                                                                        reportIndexResult2.setIndexScore(100 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                    }
                                                                } else {
                                                                    reportIndexResult.setIndexScore(0 * indexConfig3.get(j).getIndexWeight());
                                                                    if (reportIndexResult2.getIndexScore()!=null){
                                                                        reportIndexResult2.setIndexScore(0 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                                    }else {
                                                                        reportIndexResult2.setIndexScore(0 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                    }
                                                                }
                                                            } else if (indexConfig3.get(j).getIndexCode().equals("10039")) {
                                                                reportIndexResult.setIndexData(String.valueOf(waterAlarmWcl));
                                                                if (waterAlarmWcl > 0) {
                                                                    reportIndexResult.setIndexScore(-15 * indexConfig3.get(j).getIndexWeight());
                                                                    if (reportIndexResult2.getIndexScore()!=null){
                                                                        reportIndexResult2.setIndexScore(-15 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                                    }else {
                                                                        reportIndexResult2.setIndexScore(-15 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                    }
                                                                } else if (clHydrantWaterDays < 7) {
                                                                    reportIndexResult.setIndexScore(100 * indexConfig3.get(j).getIndexWeight());
                                                                    if (reportIndexResult2.getIndexScore()!=null){
                                                                        reportIndexResult2.setIndexScore(100 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                                    }else {
                                                                        reportIndexResult2.setIndexScore(100 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                    }
                                                                } else if (clHydrantWaterDays < 30) {
                                                                    reportIndexResult.setIndexScore(25 * indexConfig3.get(j).getIndexWeight());
                                                                    if (reportIndexResult2.getIndexScore()!=null){
                                                                        reportIndexResult2.setIndexScore(25 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                                    }else {
                                                                        reportIndexResult2.setIndexScore(25 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                    }
                                                                } else {
                                                                    reportIndexResult.setIndexScore(0 * indexConfig3.get(j).getIndexWeight());
                                                                    if (reportIndexResult2.getIndexScore()!=null){
                                                                        reportIndexResult2.setIndexScore(0 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                                    }else {
                                                                        reportIndexResult2.setIndexScore(0 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                    }
                                                                }
                                                            }
                                                        }
                                                        this.save(reportIndexResult);
                                                    }
                                                    if (indexConfig3.get(j).getSeniorIndex().equals(12)) {
                                                        if (list4.size() == 0) {
                                                            reportIndexResult.setScoreType(0);
                                                            if (indexConfig3.get(j).getIndexCode().equals("10040")) {
                                                                reportIndexResult.setIndexScore(-50 * indexConfig3.get(j).getIndexWeight());
                                                                if (reportIndexResult2.getIndexScore()!=null){
                                                                    reportIndexResult2.setIndexScore(-50 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                                }else {
                                                                    reportIndexResult2.setIndexScore(-50 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                }
                                                            } else if (indexConfig3.get(j).getIndexCode().equals("10041")) {
                                                                reportIndexResult.setIndexScore(-50 * indexConfig3.get(j).getIndexWeight());
                                                                if (reportIndexResult2.getIndexScore()!=null){
                                                                    reportIndexResult2.setIndexScore(-50 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                                }else {
                                                                    reportIndexResult2.setIndexScore(-50 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                }
                                                            } else {
                                                                reportIndexResult.setIndexScore(50 * indexConfig3.get(j).getIndexWeight());
                                                                if (reportIndexResult2.getIndexScore()!=null){
                                                                    reportIndexResult2.setIndexScore(50 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                                }else {
                                                                    reportIndexResult2.setIndexScore(50 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                }
                                                            }
                                                        } else {
                                                            reportIndexResult.setScoreType(1);
                                                            if (indexConfig3.get(j).getIndexCode().equals("10040")) {
                                                                reportIndexResult.setIndexData(String.valueOf(smokeOnlineRate));
                                                                if (smokeOnlineRate < 0.95) {
                                                                    reportIndexResult.setIndexScore(-100 * indexConfig3.get(j).getIndexWeight());
                                                                    if (reportIndexResult2.getIndexScore()!=null){
                                                                        reportIndexResult2.setIndexScore(-100 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                                    }else {
                                                                        reportIndexResult2.setIndexScore(-100 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                    }
                                                                } else {
                                                                    reportIndexResult.setIndexScore(0 * indexConfig3.get(j).getIndexWeight());
                                                                    if (reportIndexResult2.getIndexScore()!=null){
                                                                        reportIndexResult2.setIndexScore(0 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                                    }else {
                                                                        reportIndexResult2.setIndexScore(0 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                    }
                                                                }
                                                            } else if (indexConfig3.get(j).getIndexCode().equals("10041")) {
                                                                reportIndexResult.setIndexData(String.valueOf(smokeFaultRate));
                                                                if (smokeFaultRate > 0.05) {
                                                                    reportIndexResult.setIndexScore(-100 * indexConfig3.get(j).getIndexWeight());
                                                                    if (reportIndexResult2.getIndexScore()!=null){
                                                                        reportIndexResult2.setIndexScore(-100 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                                    }else {
                                                                        reportIndexResult2.setIndexScore(-100 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                    }
                                                                } else {
                                                                    reportIndexResult.setIndexScore(0 * indexConfig3.get(j).getIndexWeight());
                                                                    if (reportIndexResult2.getIndexScore()!=null){
                                                                        reportIndexResult2.setIndexScore(0 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                                    }else {
                                                                        reportIndexResult2.setIndexScore(0 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                    }
                                                                }
                                                            } else if (indexConfig3.get(j).getIndexCode().equals("10042")) {
                                                                reportIndexResult.setIndexData(String.valueOf(smokeOnlineRate));
                                                                if (smokeOnlineRate > 0.9) {
                                                                    reportIndexResult.setIndexScore(100 * indexConfig3.get(j).getIndexWeight());
                                                                    if (reportIndexResult2.getIndexScore()!=null){
                                                                        reportIndexResult2.setIndexScore(100 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                                    }else {
                                                                        reportIndexResult2.setIndexScore(100 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                    }
                                                                } else {
                                                                    reportIndexResult.setIndexScore(0 * indexConfig3.get(j).getIndexWeight());
                                                                    if (reportIndexResult2.getIndexScore()!=null){
                                                                        reportIndexResult2.setIndexScore(0 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                                    }else {
                                                                        reportIndexResult2.setIndexScore(0 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                    }
                                                                }
                                                            } else if (indexConfig3.get(j).getIndexCode().equals("10043")) {
                                                                reportIndexResult.setIndexData(String.valueOf(smokeFaultRate));
                                                                if (smokeFaultRate < 0.05) {
                                                                    reportIndexResult.setIndexScore(100 * indexConfig3.get(j).getIndexWeight());
                                                                    if (reportIndexResult2.getIndexScore()!=null){
                                                                        reportIndexResult2.setIndexScore(100 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                                    }else {
                                                                        reportIndexResult2.setIndexScore(100 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                    }
                                                                } else {
                                                                    reportIndexResult.setIndexScore(0 * indexConfig3.get(j).getIndexWeight());
                                                                    if (reportIndexResult2.getIndexScore()!=null){
                                                                        reportIndexResult2.setIndexScore(0 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                                    }else {
                                                                        reportIndexResult2.setIndexScore(0 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                    }
                                                                }
                                                            } else if (indexConfig3.get(j).getIndexCode().equals("10044")) {
                                                                reportIndexResult.setIndexData(String.valueOf(smokeAlarmWcl));
                                                                if (smokeAlarmWcl > 0) {
                                                                    reportIndexResult.setIndexScore(-15 * indexConfig3.get(j).getIndexWeight());
                                                                    if (reportIndexResult2.getIndexScore()!=null){
                                                                        reportIndexResult2.setIndexScore(-15 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                                    }else {
                                                                        reportIndexResult2.setIndexScore(-15 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                    }
                                                                } else if (clSmokeDays < 7) {
                                                                    reportIndexResult.setIndexScore(100 * indexConfig3.get(j).getIndexWeight());
                                                                    if (reportIndexResult2.getIndexScore()!=null){
                                                                        reportIndexResult2.setIndexScore(100 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                                    }else {
                                                                        reportIndexResult2.setIndexScore(100 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                    }
                                                                } else if (clSmokeDays < 30) {
                                                                    reportIndexResult.setIndexScore(25 * indexConfig3.get(j).getIndexWeight());
                                                                    if (reportIndexResult2.getIndexScore()!=null){
                                                                        reportIndexResult2.setIndexScore(25 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                                    }else {
                                                                        reportIndexResult2.setIndexScore(25 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                    }
                                                                } else {
                                                                    reportIndexResult.setIndexScore(0 * indexConfig3.get(j).getIndexWeight());
                                                                    if (reportIndexResult2.getIndexScore()!=null){
                                                                        reportIndexResult2.setIndexScore(0 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                                    }else {
                                                                        reportIndexResult2.setIndexScore(0 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                    }
                                                                }
                                                            }
                                                        }
                                                        this.save(reportIndexResult);
                                                    }
                                                    if (indexConfig3.get(j).getSeniorIndex().equals(13)) {
                                                        reportIndexResult.setScoreType(0);
                                                        if (indexConfig3.get(j).getIndexCode().equals("10046") || indexConfig3.get(j).getIndexCode().equals("10048")) {
                                                            reportIndexResult.setIndexScore(0 * indexConfig3.get(j).getIndexWeight());
                                                            if (reportIndexResult2.getIndexScore()!=null){
                                                                reportIndexResult2.setIndexScore(0 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                            }else {
                                                                reportIndexResult2.setIndexScore(0 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                            }
                                                        } else {
                                                            reportIndexResult.setIndexScore(50 * indexConfig3.get(j).getIndexWeight());
                                                            if (reportIndexResult2.getIndexScore()!=null){
                                                                reportIndexResult2.setIndexScore(50 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                            }else {
                                                                reportIndexResult2.setIndexScore(50 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                            }
                                                        }
                                                        this.save(reportIndexResult);
                                                    }
                                                    if (indexConfig3.get(j).getSeniorIndex().equals(14) || indexConfig3.get(j).getSeniorIndex().equals(15) || indexConfig3.get(j).getSeniorIndex().equals(16) || indexConfig3.get(j).getSeniorIndex().equals(17)) {
                                                        if (indexConfig3.get(j).getIndexCode().equals("10054")) {
                                                            if (CollectionUtils.isNotEmpty(list9)) {
                                                                reportIndexResult.setIndexData(list9.get(0).getFireManageName());
                                                            }
                                                            if (list9.size() == 0 || list9.get(0).getFireManageName() == null || list9.get(0).getFireManageName().equals("暂缺") || list9.get(0).getFireManageName().equals("")) {
                                                                reportIndexResult.setIndexScore(0 * indexConfig3.get(j).getIndexWeight());
                                                                if (reportIndexResult2.getIndexScore()!=null){
                                                                    reportIndexResult2.setIndexScore(0 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                                }else {
                                                                    reportIndexResult2.setIndexScore(0 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                }
                                                            } else {
                                                                reportIndexResult.setIndexScore(100 * indexConfig3.get(j).getIndexWeight());
                                                                if (reportIndexResult2.getIndexScore()!=null){
                                                                    reportIndexResult2.setIndexScore(100 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                                }else {
                                                                    reportIndexResult2.setIndexScore(100 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                                }
                                                            }
                                                            reportIndexResult.setScoreType(1);
                                                        } else {
                                                            reportIndexResult.setIndexScore(50 * indexConfig3.get(j).getIndexWeight());
                                                            if (reportIndexResult2.getIndexScore()!=null){
                                                                reportIndexResult2.setIndexScore(50 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight()+reportIndexResult2.getIndexScore());
                                                            }else {
                                                                reportIndexResult2.setIndexScore(50 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                            }
                                                            reportIndexResult.setScoreType(0);
                                                        }
                                                        this.save(reportIndexResult);
                                                    }
                                                    if (indexConfig3.get(j).getSeniorIndex().equals(18) || indexConfig3.get(j).getSeniorIndex().equals(19) || indexConfig3.get(j).getSeniorIndex().equals(20) || indexConfig3.get(j).getSeniorIndex().equals(21)) {
                                                        if (indexConfig3.get(j).getIndexCode().equals("10067")) {
                                                            reportIndexResult.setIndexData(String.valueOf(list10.size()));
                                                            if (list10.size() == 0) {
                                                                reportIndexResult.setIndexScore(0 * indexConfig3.get(j).getIndexWeight());
                                                                reportIndexResult2.setIndexScore(0 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                            } else if (list10.size() < 4) {
                                                                reportIndexResult.setIndexScore(-20 * indexConfig3.get(j).getIndexWeight());
                                                                reportIndexResult2.setIndexScore(-20 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                            } else if (list10.size() < 7) {
                                                                reportIndexResult.setIndexScore(-50 * indexConfig3.get(j).getIndexWeight());
                                                                reportIndexResult2.setIndexScore(-50 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                            } else {
                                                                reportIndexResult.setIndexScore(-100 * indexConfig3.get(j).getIndexWeight());
                                                                reportIndexResult2.setIndexScore(-100 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                            }
                                                            reportIndexResult.setScoreType(1);
                                                        } else if (indexConfig3.get(j).getIndexCode().equals("10068")) {
                                                            reportIndexResult.setIndexData(String.valueOf(list11.size()));
                                                            if (list11.size() == 0) {
                                                                reportIndexResult.setIndexScore(0 * indexConfig3.get(j).getIndexWeight());
                                                                reportIndexResult2.setIndexScore(0 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                            } else if (list11.size() == 1) {
                                                                reportIndexResult.setIndexScore(-20 * indexConfig3.get(j).getIndexWeight());
                                                                reportIndexResult2.setIndexScore(-20 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                            } else if (list11.size() == 2) {
                                                                reportIndexResult.setIndexScore(-40 * indexConfig3.get(j).getIndexWeight());
                                                                reportIndexResult2.setIndexScore(-40 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                            } else if (list11.size() == 3) {
                                                                reportIndexResult.setIndexScore(-80 * indexConfig3.get(j).getIndexWeight());
                                                                reportIndexResult2.setIndexScore(-80 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                            } else {
                                                                reportIndexResult.setIndexScore(-100 * indexConfig3.get(j).getIndexWeight());
                                                                reportIndexResult2.setIndexScore(-100 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                            }
                                                            reportIndexResult.setScoreType(1);
                                                        } else if (indexConfig3.get(j).getIndexCode().equals("10069")) {
                                                            reportIndexResult.setIndexData(String.valueOf(list12.size()));
                                                            if (list12.size() < 5) {
                                                                reportIndexResult.setIndexScore(-25 * list12.size() * indexConfig3.get(j).getIndexWeight());
                                                                reportIndexResult2.setIndexScore(-25 * list12.size() * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                            } else {
                                                                reportIndexResult.setIndexScore(-100 * indexConfig3.get(j).getIndexWeight());
                                                                reportIndexResult2.setIndexScore(-100 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                            }
                                                            reportIndexResult.setScoreType(1);
                                                        } else if (indexConfig3.get(j).getIndexCode().equals("10070")) {
                                                            reportIndexResult.setScoreType(0);
                                                            reportIndexResult.setIndexScore(0 * indexConfig3.get(j).getIndexWeight());
                                                            reportIndexResult2.setIndexScore(0 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                        }
                                                        this.save(reportIndexResult);
                                                    }
                                                    if (indexConfig3.get(j).getSeniorIndex().equals(22) || indexConfig3.get(j).getSeniorIndex().equals(23)) {
                                                        if (indexConfig3.get(j).getIndexCode().equals("10071")) {
                                                            reportIndexResult.setIndexData(String.valueOf(list13.size()));
                                                            reportIndexResult.setIndexScore(-100 * list13.size() * indexConfig3.get(j).getIndexWeight());
                                                            reportIndexResult2.setIndexScore(-100 * list13.size() * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                            reportIndexResult.setScoreType(1);
                                                        } else {
                                                            reportIndexResult.setIndexScore(0 * indexConfig3.get(j).getIndexWeight());
                                                            reportIndexResult2.setIndexScore(0 * indexConfig3.get(j).getIndexWeight()* indexConfig2.get(k).getIndexWeight());
                                                            reportIndexResult.setScoreType(0);
                                                        }
                                                        this.save(reportIndexResult);
                                                    }
                                                }
                                            }
                                        }
                                        this.save(reportIndexResult2);
                                        if (indexConfig1.get(l).getId().equals(5)||indexConfig1.get(l).getId().equals(6)){
                                            if (reportIndexResult1.getIndexScore()!=null){
                                                reportIndexResult1.setIndexScore(reportIndexResult2.getIndexScore()* indexConfig1.get(l).getIndexWeight()+reportIndexResult1.getIndexScore());
                                            }else {
                                                reportIndexResult1.setIndexScore(100*indexConfig1.get(l).getIndexWeight()+reportIndexResult2.getIndexScore()* indexConfig1.get(l).getIndexWeight());
                                            }
                                        }else {
                                            if (reportIndexResult1.getIndexScore()!=null){
                                                reportIndexResult1.setIndexScore(reportIndexResult2.getIndexScore()* indexConfig1.get(l).getIndexWeight()+reportIndexResult1.getIndexScore());
                                            }else {
                                                reportIndexResult1.setIndexScore(reportIndexResult2.getIndexScore()* indexConfig1.get(l).getIndexWeight());
                                            }
                                        }
                                    }
                                }
                            }
                            this.save(reportIndexResult1);
                            if (reportResult.getOverallScore()!=null){
                                reportResult.setOverallScore(reportIndexResult1.getIndexScore()+reportResult.getOverallScore());
                            }else {
                                reportResult.setOverallScore(reportIndexResult1.getIndexScore());
                            }
                        }
                    }
                    reportResultService.save(reportResult);
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    @Override
    public List<IndexResultVo> indexResultSelect(Integer id, String createDate) {
        List<IndexResultVo> list = new ArrayList<>();
        List<IndexResult1Vo> list2 = new ArrayList<>();
        LambdaQueryWrapper<ReportResult> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper.select(ReportResult::getId,ReportResult::getObjectId,ReportResult::getCreateDate,
                ReportResult::getOverallScore)
                .eq(ReportResult::getId,id);
        List<ReportResult> list1 = reportResultService.list(queryWrapper);
        IndexResultVo indexResultVo = new IndexResultVo();
        if (CollectionUtils.isNotEmpty(list1)) {
            indexResultVo.setCreateDate(list1.get(0).getCreateDate());
            indexResultVo.setId(list1.get(0).getId());
            indexResultVo.setOverallScore(list1.get(0).getOverallScore());
            LambdaQueryWrapper<ReportIndexResult> queryWrapper1 = Wrappers.lambdaQuery();
            queryWrapper1
                    .eq(ReportIndexResult::getObjectId,list1.get(0).getObjectId())
                    .eq(ReportIndexResult::getCreateDate,list1.get(0).getCreateDate());
            List<ReportIndexResult> list3 = this.list(queryWrapper1);
            if (CollectionUtils.isNotEmpty(list3)) {
                List<String> indexIdList = new ArrayList<>();
                for (int i = 0; i < list3.size(); i++) {
                    indexIdList.add(list3.get(i).getIndexCode());
                }
                LambdaQueryWrapper<ReportIndexConfig> queryWrapper2 = Wrappers.lambdaQuery();
                queryWrapper2
                        .in(ReportIndexConfig::getIndexCode,indexIdList);
//                        .eq(ReportIndexConfig::getIndexGrade,1);
                List<ReportIndexConfig> list4 = reportIndexConfigService.list(queryWrapper2);
                for (int j = 0; j < list3.size(); j++) {
                    IndexResult1Vo indexResult1Vo = new IndexResult1Vo();
                    if (CollectionUtils.isNotEmpty(list4)){
                        for (int k = 0; k < list4.size(); k++) {
                            if (list3.get(j).getIndexCode().equals(list4.get(k).getIndexCode()) && list4.get(k).getIndexGrade().equals(1)){
                                indexResult1Vo.setId(list3.get(j).getId());
                                indexResult1Vo.setIndexData(list3.get(j).getIndexData());
                                indexResult1Vo.setIndexName(list3.get(j).getIndexName());
                                indexResult1Vo.setIndexScore(list3.get(j).getIndexScore());
                                indexResult1Vo.setIndexWeight(list4.get(k).getIndexWeight());
                                indexResult1Vo.setScoreDesc(list3.get(j).getScoreDesc());
                                indexResult1Vo.setScoreType(list3.get(j).getScoreType());
                                List<IndexResult2Vo> list5 = new ArrayList<>();
                                for (int m = 0; m < list4.size(); m++) {
                                    if (list4.get(m).getSeniorIndex().equals(list4.get(k).getId()) && list4.get(m).getIndexGrade().equals(2)) {
                                        for (int l = 0; l < list3.size(); l++) {
                                            if (list3.get(l).getIndexCode().equals(list4.get(m).getIndexCode())) {
                                                IndexResult2Vo indexResult2Vo = new IndexResult2Vo();
                                                indexResult2Vo.setId(list3.get(l).getId());
                                                indexResult2Vo.setIndexData(list3.get(l).getIndexData());
                                                indexResult2Vo.setIndexName(list3.get(l).getIndexName());
                                                indexResult2Vo.setIndexScore(list3.get(l).getIndexScore());
                                                indexResult2Vo.setIndexWeight(list4.get(m).getIndexWeight());
                                                indexResult2Vo.setScoreDesc(list3.get(l).getScoreDesc());
                                                indexResult2Vo.setScoreType(list3.get(l).getScoreType());
                                                List<IndexResult3Vo> list6 = new ArrayList<>();
                                                for (int o = 0; o < list4.size(); o++) {
                                                    if (list4.get(o).getSeniorIndex().equals(list4.get(m).getId()) && list4.get(o).getIndexGrade().equals(3)) {
                                                        for (int n = 0; n < list3.size(); n++) {
                                                            if (list3.get(n).getIndexCode().equals(list4.get(o).getIndexCode())) {
                                                                IndexResult3Vo indexResult3Vo = new IndexResult3Vo();
                                                                indexResult3Vo.setId(list3.get(n).getId());
                                                                indexResult3Vo.setIndexData(list3.get(n).getIndexData());
                                                                indexResult3Vo.setIndexName(list3.get(n).getIndexName());
                                                                indexResult3Vo.setIndexScore(list3.get(n).getIndexScore());
                                                                indexResult3Vo.setIndexWeight(list4.get(o).getIndexWeight());
                                                                indexResult3Vo.setScoreDesc(list3.get(n).getScoreDesc());
                                                                indexResult3Vo.setScoreType(list3.get(n).getScoreType());
                                                                list6.add(indexResult3Vo);
                                                            }
                                                        }
                                                    }
                                                }
                                                indexResult2Vo.setIndexResult1List(list6);
                                                list5.add(indexResult2Vo);
                                            }
                                        }
                                    }
                                }
                                indexResult1Vo.setIndexResult1List(list5);
                                list2.add(indexResult1Vo);
                            }
                        }
                    }
                }
            }
            indexResultVo.setIndexResult1List(list2);
            list.add(indexResultVo);
        }

        return list;
    }
}
